@@ -103,7 +103,7 @@ class KNativeConsumer(threading.Thread):
         print("**** Print the Messages ****")
         
         try:
-            self.consumer.subscribe([self.topics])
+            # self.consumer.subscribe([self.topics])
 
             for message in self.consumer:
                 print("topic={} partition={} offset={} key={} value={}".format(message.topic,
@@ -112,6 +112,7 @@ class KNativeConsumer(threading.Thread):
                                                                         message.key,
                                                                         message.value))
                 print('consumed: {}'.format(message.value()))
+                self.logger.error('consumed: {}'.format(message.value()))
         except Exception as ex:
                 print("Inexception")
                 print("Exception while getting the message - {}".format(ex))
@@ -119,21 +120,21 @@ class KNativeConsumer(threading.Thread):
                 self.logger.error("We have a %s", "major problem. We got an exception!", exc_info=1)
 
     def getMetric(self):
-        for p in self.consumer.partitions_for_topic(self.topics):
-            tp = TopicPartition(self.topics, p)
-            self.consumer.assign([tp])
-            committed_offset = self.consumer.committed(tp)
-            if committed_offset is None:
-                committed_offset = 0
-            for _, v in self.consumer.end_offsets([tp]).items():
-                latest_offset = v
-            print("committed_offset")
-            print(committed_offset)
-            self.logger.error(committed_offset)
-            print("latest offset")
-            print(latest_offset)
-            self.logger.error(latest_offset)
-            print("lag")
-            print(latest_offset - committed_offset)
+        tp = self.consumer.assignment()
+        committed_offset = self.consumer.committed(tp)
+        print("committed_offset")
+        print(committed_offset)
+        if committed_offset is None:
+            committed_offset = 0
+        for _, v in self.consumer.end_offsets([tp]).items():
+            latest_offset = v
+        print("committed_offset")
+        print(committed_offset)
+        self.logger.error(committed_offset)
+        print("latest offset")
+        print(latest_offset)
+        self.logger.error(latest_offset)
+        print("lag")
+        print(latest_offset - committed_offset)
 
         self.consumer.close(autocommit=False)
